#!/bin/bash
#
# Copyright (C) 2023 MOXA Inc. All rights reserved.
# This software is distributed under the terms of the MOXA SOFTWARE NOTICE.
# See the file LICENSE for details.
#
# Authors:
#       2023  Wilson YS Huang  <wilsonys.huang@moxa.com>

source "${INSTL_SCRIPT_DIR}/lib/logger.sh"
log::init "${INSTL_LOG_FILE}" "${INSTL_LOG_LEVEL}"

set -e

install_debian_based_dev_tools() {
        apt-get update
        apt-get install \
                build-essential \
                linux-headers-"$(uname -r)" \
                dmidecode -y
}

install_redhat_based_dev_tools() {
        yum makecache
        yum groupinstall "Development Tools" -y
        yum install \
                kernel-devel-"$(uname -r)" \
                kernel-headers-"$(uname -r)" \
                dmidecode -y
}

main() {
        local exit_code

        log::debug "LINUX_DISTRO_ID=${LINUX_DISTRO_ID}"

        case "${LINUX_DISTRO_ID}" in
        "debian" | "ubuntu")
                install_debian_based_dev_tools >>"${INSTL_LOG_FILE}" 2>&1
                exit_code=${?}
                ;;
        "rhel" | "centos")
                install_redhat_based_dev_tools >>"${INSTL_LOG_FILE}" 2>&1
                exit_code=${?}
                ;;
        *)
                exit_code=1
                ;;
        esac

        exit ${exit_code}
}

main
