#!/bin/bash
#
# Copyright (C) 2023 MOXA Inc. All rights reserved.
# This software is distributed under the terms of the MOXA SOFTWARE NOTICE.
# See the file LICENSE for details.
#
# Authors:
#       2023  Wilson YS Huang  <wilsonys.huang@moxa.com>

util::is_root_user() {
        [[ "$(id -u)" -eq 0 ]]
}

util::is_dir() {
        [[ -d "$1" ]]
}

util::is_empty_str() {
        [[ -z "$1" ]]
}

util::is_exists() {
        [[ -e "$1" ]]
}

util::is_file() {
        [[ -f "$1" ]]
}

util::parse_product_file() {
        local file_path
        local distro_id
        local process_fn
        local current_section
        local ret

        file_path="$1"
        distro_id="$2"
        process_fn="$3"
        ret=1

        if util::is_exists "${file_path}"; then
                # Read from fd=3 instead of the stdin
                while read -u 3 -r line; do
                        if [[ $line =~ ^\[(.*)\]$ ]]; then
                                current_section=${BASH_REMATCH[1]}
                        elif ! util::is_empty_str "$line" && [[ "${distro_id}" == "$current_section" ]]; then
                                IFS=', ' read -r -a fields <<<"$line"

                                if [ ${#fields[@]} -ne 3 ]; then
                                        log::error "Invalid config format in line: $line"
                                        exit 1
                                fi

                                os_version=${fields[0]}
                                repo_name=${fields[1]}
                                repo_tag=${fields[2]}

                                $process_fn "${os_version}" "${repo_name}" "${repo_tag}"
                                ((ret *= $?))
                        fi
                done 3<"${file_path}"
        fi

        return $ret
}

util::confirm_prompt() {
        local prompt_msg
        local auto_yes
        prompt_msg="$1"
        auto_yes="$2"

        if [[ $auto_yes = false ]]; then
                read -r -p "${prompt_msg} [Y/n]" response
                if [[ "$response" =~ ^([yY][eE][sS]|[yY])$ ]]; then
                        return 0
                else
                        return 1
                fi
        else
                return 0
        fi
}
